@@ -60,6 +60,7 @@ GtkWidget *totem_pp_create (void);
 
 #define VOLUME_DOWN_OFFSET (-0.08)
 #define VOLUME_UP_OFFSET (0.08)
+#define MINIMUM_VIDEO_SIZE 150
 
 /* For newer D-Bus version */
 #ifndef DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT
@@ -647,17 +648,12 @@ totem_embedded_launch_player (TotemEmbedded *embedded,
 		uri = embedded->current_uri;
 	}
 
-#if GTK_CHECK_VERSION(2,13,0)
 	ctx = G_APP_LAUNCH_CONTEXT (gdk_app_launch_context_new ());
 	screen = gtk_widget_get_screen (embedded->window);
 	gdk_app_launch_context_set_screen (GDK_APP_LAUNCH_CONTEXT (ctx), screen);
 
 	gdk_app_launch_context_set_timestamp (GDK_APP_LAUNCH_CONTEXT (ctx), user_time);
 	gdk_app_launch_context_set_icon (GDK_APP_LAUNCH_CONTEXT (ctx), g_app_info_get_icon (embedded->app));
-#else
-	ctx = NULL;
-	screen = NULL;
-#endif
 
 	result = g_app_info_launch_uris (embedded->app, uris, ctx, NULL);
 
@@ -1099,7 +1095,7 @@ totem_embedded_update_menu (TotemEmbedded *emb)
 	emb->menu_item = item;
 
 	menu = GTK_MENU_SHELL (gtk_builder_get_object (emb->menuxml, "menu"));
-	gtk_menu_shell_prepend (menu, item);
+	gtk_menu_shell_insert (menu, item, 1);
 }
 
 static void
@@ -1651,6 +1647,15 @@ controls_size_allocate_cb (GtkWidget *controls,
 }
 #endif
 
+static void
+video_widget_size_allocate_cb (GtkWidget *controls,
+			       GtkAllocation *allocation,
+			       BaconVideoWidget *bvw)
+{
+	bacon_video_widget_set_show_visuals (bvw, allocation->height > MINIMUM_VIDEO_SIZE);
+	g_signal_handlers_disconnect_by_func (controls, G_CALLBACK (video_widget_size_allocate_cb), NULL);
+}
+
 static void
 totem_embedded_action_volume_relative (TotemEmbedded *emb, double off_pct)
 {
@@ -1833,7 +1838,10 @@ totem_embedded_construct (TotemEmbedded *emb,
 		/* FIXME: why can't this wait until the whole window is realised? */
 		gtk_widget_realize (GTK_WIDGET (emb->bvw));
 		gtk_widget_show (GTK_WIDGET (emb->bvw));
-		bacon_video_widget_set_show_visuals (emb->bvw, TRUE);
+
+		/* Let us know when the size has been allocated for the video widget */
+		g_signal_connect_after (G_OBJECT (emb->bvw), "size-allocate",
+					G_CALLBACK (video_widget_size_allocate_cb), emb->bvw);
 	} else if (emb->audioonly != FALSE) {
 		gtk_widget_hide (container);
 	}
@@ -2070,7 +2078,7 @@ entry_parsed (TotemPlParser *parser,
 
 	item = g_new0 (TotemPlItem, 1);
 	item->uri = g_strdup (uri);
-	item->title = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_TITLE);
+	item->title = g_strdup (g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_TITLE));
 	item->duration = duration;
 	item->starttime = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_STARTTIME), FALSE);
 
