@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA.
  *
  * Thursday 03 May 2007: Bastien Nocera: Add exception clause.
  * See license_change file for details.
@@ -64,7 +64,7 @@ void       ev_sidebar_add_page     (EvSidebar   *ev_sidebar,
 void       ev_sidebar_set_current_page
 				   (EvSidebar *ev_sidebar,
 				    const char *page_id);
-const char *ev_sidebar_get_current_page
+char      *ev_sidebar_get_current_page
 				   (EvSidebar *ev_sidebar);
 void        ev_sidebar_remove_page (EvSidebar   *ev_sidebar,
 				    const gchar *page_id);
