@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301  USA.
 
    Author: Bastien Nocera <hadess@hadess.net>
  */
@@ -29,7 +29,6 @@
 
 #ifndef HAVE_GTK_ONLY
 
-#include <libgnome/gnome-config.h>
 #include <libgnomeui/gnome-client.h>
 
 static char *
@@ -122,17 +121,17 @@ totem_session_setup (Totem *totem, char **argv)
 void
 totem_session_restore (Totem *totem, char **filenames)
 {
-	char *mrl, *uri;
+	char *mrl, *uri, *subtitle;
 
 	g_return_if_fail (filenames[0] != NULL);
 	uri = filenames[0];
+	subtitle = NULL;
 
 	totem_signal_block_by_data (totem->playlist, totem);
 
-	if (totem_playlist_add_mrl (totem->playlist, uri, NULL) == FALSE)
-	{
+	if (totem_playlist_add_mrl_with_cursor (totem->playlist, uri, NULL) == FALSE) {
 		totem_signal_unblock_by_data (totem->playlist, totem);
-		totem_action_set_mrl (totem, NULL);
+		totem_action_set_mrl (totem, NULL, NULL);
 		g_free (uri);
 		return;
 	}
@@ -141,18 +140,15 @@ totem_session_restore (Totem *totem, char **filenames)
 
 	if (totem->index != 0)
 		totem_playlist_set_current (totem->playlist, totem->index);
-	mrl = totem_playlist_get_current_mrl (totem->playlist);
+	mrl = totem_playlist_get_current_mrl (totem->playlist, &subtitle);
 
-	totem_action_set_mrl_with_warning (totem, mrl, FALSE);
+	totem_action_set_mrl_with_warning (totem, mrl, subtitle, FALSE);
 
-	if (totem->seek_to != 0)
-	{
-		bacon_video_widget_seek_time (totem->bvw,
-				totem->seek_to, NULL);
-	}
-	bacon_video_widget_pause (totem->bvw);
+	/* We do the seeking after being told that the stream is seekable,
+	 * not straight away */
 
 	g_free (mrl);
+	g_free (subtitle);
 
 	return;
 }
